@@ -34,9 +34,9 @@ use warnings;
 use Role::Tiny::With;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-02-20'; # DATE
+our $DATE = '2023-02-24'; # DATE
 our $DIST = 'TableDataRoles-Standard'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 with 'TableDataRole::Test::Source::CSVInFile::Select';
 
@@ -55,7 +55,7 @@ TableDataRole::Test::Source::CSVInFile::Select - Some English words with Indones
 
 =head1 VERSION
 
-This document describes version 0.014 of TableDataRole::Test::Source::CSVInFile::Select (from Perl distribution TableDataRoles-Standard), released on 2022-02-20.
+This document describes version 0.015 of TableDataRole::Test::Source::CSVInFile::Select (from Perl distribution TableDataRoles-Standard), released on 2023-02-24.
 
 =head1 HOMEPAGE
 
@@ -82,13 +82,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2021 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2021 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
